<?php

class PortfolioMedia extends FluxusPage {

    const POST_TYPE = 'project_media';

    protected $META_PREFIX = 'project_media_';

    protected $meta_data_defaults = array(
            'type'          => 'image',
            'description'   => '',
            'attachment_id' => '',
            'screenshot_id' => '',
            'embed'         => '',
            'featured'      => 0,
            'published'     => 1
        );
    protected $image_data = array();

    function to_array() {

        $this->fetch_post()->fetch_post_meta();

        $thumbnail_url = $this->get_thumbnail( 'thumbnail' );

        return array_merge( $this->meta_data_defaults, array(
                'id'             => $this->post->ID,
                'order'          => $this->post->menu_order,
                'filename'       => $this->get_filename(),
                'type'           => $this->meta_type,
                'description'    => $this->meta_description,
                'embed'          => $this->meta_embed,
                'featured'       => $this->meta_featured,
                'attachment_id'  => $this->meta_attachment_id,
                'thumbnail_url'  => $thumbnail_url ? $thumbnail_url['src'] : '',
                'screenshot_id'  => $this->meta_screenshot_id,
                'published'      => $this->meta_published
            )
        );

    }

    /**
     * Return meta description or if empty return attachment's post_title.
     */
    function get_alt() {

        $alt = trim( strip_tags( $this->meta_description ) );

        if ( ! $alt ) {
            if ( $this->is_image() ) {
                $post = get_post( $this->meta_attachment_id );
                if ( is_object( $post ) && $post->post_title ) {
                    $alt = $post->post_title;
                }
            }
        }

        return $alt;

    }

    /**
     * Arguments: (string|array) $sizes
     * Returns image url, width, height and ratio for the first image size
     *   that is found. If no image with specified size is found,
     *   then returns original image (not-resizes).
     * )
     */
    function get_thumbnail( $sizes = 'fluxus-thumbnail' ) {
        if ( is_array( $sizes ) ) {
            $size = $sizes[0];
        } else {
            $size = $sizes;
        }

        $attachment_id = false;
        $image_data = false;

        if ( $this->is_video() ) {
            if ( is_numeric( $this->meta_screenshot_id ) ) {
                $attachment_id = $this->meta_screenshot_id;
            }
        } else {
            $attachment_id = $this->meta_attachment_id;
        }

        if ( $attachment_id ) {
            $image_data = image_get_intermediate_size( $attachment_id, $size );

            if ( $image_data ) {
                $image_data['src'] = $image_data['url'];
                $image_data['ratio'] = $this->calculate_ratio( $image_data['width'], $image_data['height'] );
            } else {
                if ( !is_array( $sizes ) || count( $sizes ) == 1 ) {
                    $url = wp_get_attachment_url( $attachment_id );
                    $meta = wp_get_attachment_metadata( $attachment_id );
                    if ( $url ) {
                        $image_data = array(
                            'src'    => $url,
                            'width'  => $meta['width'],
                            'height' => $meta['height'],
                            'ratio'  => $this->calculate_ratio( $meta['width'], $meta['height'] )
                        );
                    }
                }
            }
        }

        if ( $image_data ) {
            return $image_data;
        }

        if ( is_array( $sizes ) && count( $sizes ) > 1 ) {
            array_shift( $sizes );
            return $this->get_thumbnail( $sizes );
        } else {
            return array();
        }

    }

    function get_filename() {
        return pathinfo( wp_get_attachment_url( $this->meta_data['attachment_id'] ), PATHINFO_BASENAME );
    }

    function is_video() {
        return $this->meta_type == 'video';
    }

    function get_video_size() {

        $result = array(
                'width'  => '',
                'height' => '',
                'ratio'  => ''
            );

        if ( $this->is_video() && $this->meta_embed ) {

            preg_match( '/width="(\d+)"/i', $this->meta_embed, $width_matches );
            preg_match( '/height="(\d+)"/i', $this->meta_embed, $height_matches );

            if ( is_array( $width_matches ) && isset( $width_matches[1] ) ) {
                $result['width'] = $width_matches[1];
            }

            if ( is_array( $height_matches ) && isset( $height_matches[1] ) ) {
                $result['height'] = $height_matches[1];
            }

            if ( $result['width'] && $result['height'] ) {
                $ratio = $result['width'] / $result['height'];
                $result['width'] = 1280;
                $result['height'] = round(1280 / $ratio);
                $result['ratio'] = $result['width'] / $result['height'];
            }

        }

        return $result;

    }

    function is_image() {
        return $this->meta_type == 'image';
    }

    protected function calculate_ratio( $width, $height ) {
        return $height != 0 ? $width / $height : 1;
    }

    /**
     * ------------------------------------------------------------
     * Static Functions
     * ------------------------------------------------------------
     */

    static function get_featured_media( $post_id ) {

        $args = array(
            'posts_per_page'  => 1,
            'orderby'         => 'menu_order',
            'order'           => 'DESC',
            'meta_key'        => self::POST_TYPE . '_featured',
            'meta_value'      => '1',
            'post_type'       => self::POST_TYPE,
            'post_parent'     => $post_id,
            'post_status'     => 'any',
            'suppress_filters' => true );

        /**
         * Find any image that is set as featured.
         * @var [type]
         */
        $featured_media = get_posts( $args );

        if ( $featured_media ) {

            return new PortfolioMedia( $featured_media[0]->ID );

        } else {

            /**
             * Find first image that is published.
             */
            $args['meta_key'] = 'project_media_published';
            $args['meta_value'] = '1';

            $first_media = get_posts( $args );

            if ( $first_media ) {

                return new PortfolioMedia( $first_media[0]->ID );

            }

        }

        return false;

    }

    static function create( $parent_id, $args = array() ) {

        $all = self::all( $parent_id );

        $defaults = array(
                'post_parent'     => $parent_id,
                'post_type'       => self::POST_TYPE
            );

        $args = array_merge( $defaults, $args );

        $post_id = wp_insert_post( $args, false );

        if ( $post_id ) {
            $post = get_post( $post_id );
            $post->menu_order = $post->ID;
            wp_update_post( $post );
        }

        return new PortfolioMedia( $post_id );

    }

    static function all( $parent_id ) {

        $args = array(
                'posts_per_page'  => -1,
                'offset'          => 0,
                'orderby'         => 'menu_order',
                'order'           => 'DESC',
                'post_type'       => self::POST_TYPE,
                'post_parent'     => $parent_id,
                'post_status'     => 'any',
                'suppress_filters' => true
            );

        $posts = get_posts( $args );

        if ( $posts ) {

            foreach ( $posts as $k => $post ) {
                $posts[$k] = new PortfolioMedia( $post->ID );
            }

            return $posts;

        } else {

            return array();

        }

    }

}

