<?php

/**
 * Usage:
 *
 * TransientCaching::fetch( $key )
 *   If $key is found in transient cache, then the value will be returned,
 *   otherwise a $method_name will be called to calculate the data and store it to cache.
 */
class TransientCaching {

  static function fetch( $key, $args = array(), $expiration = 0, $method_name = '' ) {

    $value = get_transient( $key );

    // If cache doesn't exist, then let's populate it by calling appropriate method.
    if ( false === $value ) {

      if ( $method_name ) {
        $function_name = $method_name;
      } else {
        $function_name = 'store_cache_' . $key;
      }

      if ( is_callable( $function_name ) ) {

        $value = call_user_func( $function_name, $args );
        set_transient( $key, $value, $expiration );

      }

    }

    return $value;

  }

}